@@ -9,7 +9,7 @@ use base 'Exporter';
 our @EXPORT_OK = qw/encode decode/;
 
 use version;
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.2.0';
 
 use Carp;
 use Config;
@@ -216,7 +216,7 @@ has wrap_strings => (
 #pod driver.
 #pod
 #pod Other acceptable values are L<BSON::Time> (explicitly), L<DateTime>,
-#pod L<Time::Moment>, L<DateTime::Tiny>.
+#pod L<Time::Moment>, L<DateTime::Tiny>, L<Mango::BSON::Time>.
 #pod
 #pod Because BSON::Time objects have methods to convert to DateTime,
 #pod Time::Moment or DateTime::Tiny, use of this field is discouraged.  Users
@@ -617,7 +617,7 @@ BSON - BSON serialization and deserialization
 
 =head1 VERSION
 
-version v1.0.0
+version v1.2.0
 
 =head1 SYNOPSIS
 
@@ -791,7 +791,7 @@ so is somewhat backwards compatible with C<dt_type> in the L<MongoDB>
 driver.
 
 Other acceptable values are L<BSON::Time> (explicitly), L<DateTime>,
-L<Time::Moment>, L<DateTime::Tiny>.
+L<Time::Moment>, L<DateTime::Tiny>, L<Mango::BSON::Time>.
 
 Because BSON::Time objects have methods to convert to DateTime,
 Time::Moment or DateTime::Tiny, use of this field is discouraged.  Users
@@ -960,7 +960,6 @@ type deserializes to.  Footnotes indicate variations or special behaviors.
     BSON::Raw
     MongoDB::BSON::Raw[d]
     Tie::IxHash
-    Hash::Ordered
     -------------------------------------------------------------------
     arrayref                    0x04 ARRAY          arrayref
     -------------------------------------------------------------------
@@ -988,6 +987,7 @@ type deserializes to.  Footnotes indicate variations or special behaviors.
     DateTime
     DateTime::Tiny
     Time::Moment
+    Mango::BSON::Time
     -------------------------------------------------------------------
     undef                       0x0a NULL           undef
     -------------------------------------------------------------------
@@ -1087,6 +1087,9 @@ Odd-value increments of C<Y> indicate unstable ("development") releases that sho
 This module was originally written by Stefan G.  In 2014, he graciously
 transferred ongoing maintenance to MongoDB, Inc.
 
+The C<bson_xxxx> helper functions in L<BSON::Types> were inspired by similar
+work in L<Mango::BSON> by Sebastian Riedel.
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -1122,7 +1125,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Eric Daniels Pat Gunn Yury Zavarin Oleg Kostyuk
+=for stopwords Eric Daniels Olivier Duclos Pat Gunn Yury Zavarin Oleg Kostyuk
 
 =over 4
 
@@ -1132,6 +1135,10 @@ Eric Daniels <eric.daniels@mongodb.com>
 
 =item *
 
+Olivier Duclos <odc@cpan.org>
+
+=item *
+
 Pat Gunn <pgunn@mongodb.com>
 
 =item *
