@@ -6,7 +6,7 @@ package BSON::Time;
 # ABSTRACT: BSON type wrapper for date and time
 
 use version;
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.2.0';
 
 use Carp qw/croak/;
 use Config;
@@ -126,6 +126,18 @@ sub as_datetime_tiny {
     );
 }
 
+#pod =method as_mango_time
+#pod
+#pod Loads L<Mango::BSON::Time> and returns the C<value> as a L<Mango::BSON::Time>
+#pod object.
+#pod
+#pod =cut
+
+sub as_mango_time {
+    require Mango::BSON::Time;
+    return Mango::BSON::Time->new( $_[0]->{value} );
+}
+
 #pod =method as_time_moment
 #pod
 #pod Loads L<Time::Moment> and returns the C<value> as a L<Time::Moment> object.
@@ -195,7 +207,7 @@ BSON::Time - BSON type wrapper for date and time
 
 =head1 VERSION
 
-version v1.0.0
+version v1.2.0
 
 =head1 SYNOPSIS
 
@@ -239,6 +251,11 @@ Loads L<DateTime> and returns the C<value> as a L<DateTime> object.
 Loads L<DateTime::Tiny> and returns the C<value> as a L<DateTime::Tiny>
 object.
 
+=head2 as_mango_time
+
+Loads L<Mango::BSON::Time> and returns the C<value> as a L<Mango::BSON::Time>
+object.
+
 =head2 as_time_moment
 
 Loads L<Time::Moment> and returns the C<value> as a L<Time::Moment> object.
